======================
sphinxcontrib-cadquery
======================

A `Sphinx`_ extension for rendering `CadQuery`_ models.

**Development Status :: 2 - Pre-Alpha**

.. _Sphinx: https://www.sphinx-doc.org/
.. _CadQuery: https://cadquery.readthedocs.io/
